@@ -149,6 +149,11 @@ do i=1,3
   sum=sum/dble(natmtot)
   forcetot(i,:)=forcetot(i,:)-sum
 end do
+! zero force on atoms with negative mass
+do ias=1,natmtot
+  is=idxis(ias)
+  if (spmass(is).le.0.d0) forcetot(:,ias)=0.d0
+end do
 ! compute maximum force magnitude over all atoms
 forcemax=0.d0
 do ias=1,natmtot
