@@ -23,21 +23,20 @@ real(8), intent(out) :: g2rho(lmmaxvr,nrmtmax)
 real(8), intent(out) :: gvrho(lmmaxvr,nrmtmax,3)
 real(8), intent(out) :: grho2(lmmaxvr,nrmtmax)
 ! local variables
-integer is,nr,i
+integer is,nr,nri,i
 ! allocatable arrays
 real(8), allocatable :: rfmt(:,:),grfmt(:,:,:)
 allocate(rfmt(lmmaxvr,nrmtmax),grfmt(lmmaxvr,nrmtmax,3))
 is=idxis(ias)
 nr=nrmt(is)
+nri=nrmtinr(is)
 ! compute grad^2 rho in spherical coordinates
 call grad2rfmt(lmaxvr,nr,spr(:,is),lmmaxvr,rhomt(:,:,ias),rfmt)
-call dgemm('N','N',lmmaxvr,nr,lmmaxvr,1.d0,rbshtvr,lmmaxvr,rfmt,lmmaxvr,0.d0, &
- g2rho,lmmaxvr)
+call rbsht(nr,nri,rfmt,g2rho)
 ! compute grad rho in spherical coordinates
 call gradrfmt(lmaxvr,nr,spr(:,is),lmmaxvr,nrmtmax,rhomt(:,:,ias),grfmt)
 do i=1,3
-  call dgemm('N','N',lmmaxvr,nr,lmmaxvr,1.d0,rbshtvr,lmmaxvr,grfmt(:,:,i), &
-   lmmaxvr,0.d0,gvrho(:,:,i),lmmaxvr)
+  call rbsht(nr,nri,grfmt(:,:,i),gvrho(:,:,i))
 end do
 ! (grad rho)^2
 grho2(:,1:nr)=gvrho(:,1:nr,1)**2+gvrho(:,1:nr,2)**2+gvrho(:,1:nr,3)**2
