@@ -126,8 +126,6 @@ real(8), allocatable :: spvr(:,:)
 !---------------------------------------------------------------!
 !     muffin-tin radial mesh and angular momentum variables     !
 !---------------------------------------------------------------!
-! radial function integration and differentiation polynomial order
-integer nprad
 ! scale factor for number of muffin-tin points
 integer nrmtscf
 ! number of muffin-tin radial points for each species
@@ -166,7 +164,7 @@ integer lmaxinr
 integer lmmaxinr
 ! fraction of muffin-tin radius which constitutes the inner part
 real(8) fracinr
-! number of fine/coarse radial points to the inner part of the muffin-tin
+! number of fine/coarse radial points on the inner part of the muffin-tin
 integer nrmtinr(maxspecies),nrcmtinr(maxspecies)
 ! index to (l,m) pairs
 integer, allocatable :: idxlm(:,:)
@@ -180,7 +178,11 @@ integer, allocatable :: idxil(:),idxim(:)
 logical spinpol
 ! spinorb is .true. for spin-orbit coupling
 logical spinorb
-! fixspin type: 0 = none, 1 = global, 2 = local, 3 = global + local
+! fixed spin moment type
+!  0      : none
+!  1 (-1) : total moment (direction)
+!  2 (-2) : individual muffin-tin moments (direction)
+!  3 (-3) : total and muffin-tin moments (direction)
 integer fixspin
 ! dimension of magnetisation and magnetic vector fields (1 or 3)
 integer ndmag
@@ -226,6 +228,9 @@ real(8) vqcss(3)
 integer iqss
 ! number of primitive unit cells in spin-spiral supercell
 integer nscss
+! number of fixed spin direction points on the sphere for finding the magnetic
+! anisotropy energy
+integer npmae
 
 !---------------------------------------------!
 !     electric field and vector potential     !
@@ -466,6 +471,9 @@ logical trhonorm
 real(8), allocatable :: magmt(:,:,:,:)
 ! interstitial magnetisation vector field
 real(8), allocatable :: magir(:,:)
+! amount of smoothing to be applied to the density; this is the number of
+! 3-point running averages performed on the radial functions in the muffin-tins
+integer msmooth
 ! muffin-tin Coulomb potential
 real(8), allocatable :: vclmt(:,:,:)
 ! interstitial real-space Coulomb potential
@@ -561,6 +569,8 @@ real(8) chgmttot
 real(8) rwigner
 ! total moment
 real(8) momtot(3)
+! total moment magnitude
+real(8) momtotm
 ! interstitial region moment
 real(8) momir(3)
 ! muffin-tin moments
@@ -670,7 +680,7 @@ real(8) tauseq
 !     eigenvalue and occupancy variables     !
 !--------------------------------------------!
 ! number of empty states per atom and spin
-integer nempty0
+real(8) nempty0
 ! number of empty states
 integer nempty
 ! number of first-variational states
@@ -774,9 +784,9 @@ real(8) engyts
 ! total energy
 real(8) engytot
 
-!-------------------------!
-!     force variables     !
-!-------------------------!
+!------------------------------------!
+!     force and stress variables     !
+!------------------------------------!
 ! tforce is .true. if force should be calculated
 logical tforce
 ! tfibs is .true. if the IBS contribution to the force is to be calculated
@@ -795,12 +805,36 @@ real(8), allocatable :: forcetot(:,:)
 real(8), allocatable :: forcetotp(:,:)
 ! maximum force magnitude over all atoms
 real(8) forcemax
-! maximum number of geometry optimisation steps
-integer maxgeostp
-! default step size parameter for geometry optimisation
-real(8) tau0atm
+! maximum number of atomic position optimisation steps
+integer maxatpstp
+! default step size parameter for atomic position optimisation
+real(8) tau0atp
 ! step size parameters for each atom
-real(8), allocatable :: tauatm(:)
+real(8), allocatable :: tauatp(:)
+! number of strain tensors
+integer nstrain
+! strain tensors
+real(8) strain(3,3,9)
+! infinitesimal displacement parameter multiplied by the strain tensor for
+! computing the stress tensor
+real(8) deltast
+! symmetry reduced stress tensor components
+real(8) stress(9)
+! previous stress tensor
+real(8) stressp(9)
+! stress tensor component magnitude maximum
+real(8) stressmax
+! lattice vector optimisation type
+!  0 : no optimisation
+!  1 : unconstrained optimisation
+!  2 : iso-volumetric optimisation
+integer latvopt
+! maximum number of lattice vector optimisation steps
+integer maxlatvstp
+! default step size parameter for lattice vector optimisation
+real(8) tau0latv
+! step size for each stress tensor component acting on the lattice vectors
+real(8) taulatv(9)
 
 !-------------------------------!
 !     convergence variables     !
@@ -815,6 +849,8 @@ real(8) epspot
 real(8) epsengy
 ! force convergence tolerance
 real(8) epsforce
+! stress tensor convergence tolerance
+real(8) epsstress
 
 !----------------------------------------------------------!
 !     density of states, optics and response variables     !
@@ -1030,7 +1066,7 @@ real(8), parameter :: amu=1822.88848426d0
 !---------------------------------!
 ! code version
 integer version(3)
-data version / 2,1,25 /
+data version / 2,2,5 /
 ! maximum number of tasks
 integer, parameter :: maxtasks=40
 ! number of tasks
