@@ -56,7 +56,9 @@ do idm=1,ndmag
 end do
 momtot(:)=mommttot(:)+momir(:)
 ! write total moment to test file
-call writetest(450,'total moment',nv=ndmag,tol=1.d-2,rva=momtot)
+call writetest(450,'total moment',nv=ndmag,tol=2.d-2,rva=momtot)
+! total moment magnitude
+momtotm=sqrt(momtot(1)**2+momtot(2)**2+momtot(3)**2)
 return
 end subroutine
 !EOC
