@@ -70,6 +70,8 @@ call rhocore
 call charge
 ! calculate the moments
 if (spinpol) call moment
+! apply smoothing operation to the density and magnetisation if required
+call rhomagsm
 ! normalise the density
 call rhonorm
 return
