@@ -7,7 +7,7 @@ subroutine xc_c_tb09
 use modmain
 implicit none
 ! local variables
-integer is,ias,nr,ir,itp,i
+integer is,ias,nr,nri,ir,itp,i
 real(8), parameter :: alpha=-0.012d0, beta=1.023d0
 real(8) t1
 ! allocatable arrays
@@ -25,20 +25,20 @@ allocate(grfir(ngtot,3))
 call gradrf(rhomt,rhoir,grfmt,grfir)
 allocate(rfmt(lmmaxvr,nrmtmax,natmtot),rfir(ngtot))
 !$OMP PARALLEL DEFAULT(SHARED) &
-!$OMP PRIVATE(rfmt1,rfmt2,is,nr) &
+!$OMP PRIVATE(rfmt1,rfmt2) &
+!$OMP PRIVATE(is,nr,nri) &
 !$OMP PRIVATE(i,ir,itp,t1)
 !$OMP DO
 do ias=1,natmtot
   allocate(rfmt1(lmmaxvr,nrmtmax),rfmt2(lmmaxvr,nrmtmax,3))
   is=idxis(ias)
   nr=nrmt(is)
+  nri=nrmtinr(is)
 ! convert muffin-tin density to spherical coordinates
-  call dgemm('N','N',lmmaxvr,nr,lmmaxvr,1.d0,rbshtvr,lmmaxvr,rhomt(:,:,ias), &
-   lmmaxvr,0.d0,rfmt1,lmmaxvr)
+  call rbsht(nr,nri,rhomt(:,:,ias),rfmt1)
 ! convert muffin-tin gradient to spherical coordinates
   do i=1,3
-    call dgemm('N','N',lmmaxvr,nr,lmmaxvr,1.d0,rbshtvr,lmmaxvr, &
-     grfmt(:,:,ias,i),lmmaxvr,0.d0,rfmt2(:,:,i),lmmaxvr)
+    call rbsht(nr,nri,grfmt(:,:,ias,i),rfmt2(:,:,i))
   end do
 ! integrand in muffin-tin
   do ir=1,nr
@@ -48,8 +48,7 @@ do ias=1,natmtot
     end do
   end do
 ! convert to spherical harmonics
-  call dgemm('N','N',lmmaxvr,nr,lmmaxvr,1.d0,rfshtvr,lmmaxvr,rfmt1,lmmaxvr, &
-   0.d0,rfmt(:,:,ias),lmmaxvr)
+  call rfsht(nr,nri,rfmt1,rfmt(:,:,ias))
   deallocate(rfmt1,rfmt2)
 end do
 !$OMP END DO
